/* Cosar-Demir, Domestic road infrastructure and international trade, JDE final version
Table 12: time sensitivity, intensive-extensive margin */

clear all
set more off
log close _all
set matsize 5000

/*Set the directory */
cd "/Users/banudemir/Desktop/replication"

set logtype smcl
log using "Table11", replace

/* Choose country for heaviness and the share of air shipments at the industry level*/
local country="UK" 

qui{
local yearbeg  = "2004" // cutoff years for long-term differences
local yearend  = "2011"

/****************************/
// Load and prepare the data 
/***************************/
/* construct the instrument */
use "data/market_access_pg.dta",clear
keep if year==2003
keep province_code gateway distpg drs
gen RCIV    = (drs-1)*ln(distpg) // instrumental variable
keep province_code gateway RCIV 
sort province_code gateway
save temp.dta,replace

/* construct long term divided road share (ers in the paper) */
use "data/market_access_pg.dta",clear
gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.
collapse (mean) distpg drs, by(province_code gateway period)
sort province_code gateway period
reshape wide distpg drs,i(province_code gateway) j(period)
rename distpg1 distpg
gen deltadrs         = drs1-drs0
drop distpg0 drs1
sort province_code gateway
save temp2.dta,replace

/* construct industry time sensitivities */
use "data/data_pgi.dta",clear
drop if year==.
destring province_code,replace
destring gateway,replace

rename isic3_2 ind

collapse (mean) exp imp, by(province_code gateway ind year)

rename exp value1
rename imp value2
reshape long value, i(year province gateway ind) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order year province gate ind flow
drop if value==0

drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.

collapse (mean) value, by(province_code gateway flow ind period)
gen lnvalue=ln(value)

reshape wide value lnvalue,i(province_code gateway flow ind) j(period)

gen dlnval     = lnvalue1-lnvalue0
drop lnvalue0 lnvalue1
gen D_newind=1 if value1>0 & value1!=. & value0==.
replace D_newind =0 if D_newind==. 

sort province_code gateway
merge m:m province_code gateway using temp.dta
drop if _merge==2
drop _merge

sort province_code gateway
merge m:m province_code gateway using temp2.dta
drop if _merge==2
drop _merge

drop if province_code==0 | province_code==99
drop if gateway==6 

/* merge with data on industry-level air share and weight/value ratios */
replace ind="01" if ind=="1"
gen isic3_2=ind
merge m:1 isic3_2 using "data/heavy_air.dta" 
drop _merge

merge m:1 ind using "data/bw_elas.dta", keepusing(theta) // Broda Weinstein elasticities, theta
drop _merge

gen lndistpg   = ln(distpg)
gen dRC        = lndistpg * (deltadrs)

gen air        = airshr`country'
gen hea        = log(heavy`country')

drop if air==.
drop if hea==.

for X in any air hea: su X,det \ replace X=X>r(p50)

gen d_int_air  = dRC*air
gen d_int_hea  = dRC*hea
gen d_int_theta  = dRC*theta

gen d_drs_air  = deltadrs*air
gen d_drs_hea  = deltadrs*hea
gen d_drs_theta  = deltadrs*theta

gen d_drs0_air  = drs0*air
gen d_drs0_hea  = drs0*hea
gen d_drs0_theta  = drs0*theta

gen d_IV_air  = RCIV*air
gen d_IV_hea  = RCIV*hea
gen d_IV_theta  = RCIV*theta

gen dist_air  = lndistpg*air
gen dist_hea  = lndistpg*hea
gen dist_theta  = lndistpg*theta

rename province_code city

egen fes        = group(city flow)
egen fes2       = group(gateway flow)
egen fes3       = group(gateway ind flow)
egen ind2		= group(ind )
egen citygate	= group(city gateway)
egen citygate2	= group(city gateway flow)

xtset citygate2 ind2

/**************/
// Regressions
/**************/
*Intensive margin
xtivreg2 dlnval   (d_int_air d_int_hea d_drs_air d_drs_hea =d_IV_air  d_IV_hea dist_air dist_hea d_drs0_air d_drs0_hea air hea ) , cluster(citygate) fe first
estimates store col1
estadd local FixedEffects "p-g-f" , replace
estadd local cluster "p-g" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col1
estadd scalar test_kp=e(widstat): col1
*xi:ivreg dlnval i.citygate2  (d_int_air d_int_hea d_drs_air d_drs_hea =d_IV_air  d_IV_hea dist_air dist_hea d_drs0_air d_drs0_hea air hea )
*ivendog d_int_air d_int_hea d_drs_air d_drs_hea
*estadd scalar test_DWH=r(WHF): col1

/* control for industry elasticity of substitution, Broda Weinstein sigma's */

xtivreg2 dlnval (d_int_air d_int_hea d_int_theta d_drs_air d_drs_hea d_drs_theta =d_IV_air  d_IV_hea d_IV_theta  dist_air dist_hea dist_theta d_drs0_air d_drs0_hea d_drs0_theta  air hea theta) , cluster(citygate) fe first
estimates store col2
estadd local FixedEffects "p-g-f" , replace
estadd local cluster "p-g" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col2
estadd scalar test_kp=e(widstat): col2
*xi:ivreg dlnval i.citygate2  (d_int_air d_int_hea d_int_theta d_drs_air d_drs_hea d_drs_theta =d_IV_air  d_IV_hea d_IV_theta  dist_air dist_hea dist_theta d_drs0_air d_drs0_hea d_drs0_theta air hea theta)
*ivendog d_int_theta  d_int_air d_int_hea d_drs_air d_drs_hea d_drs_theta 
*estadd scalar test_DWH=r(WHF): col2

*Extensive margin
xi:xtivreg2 D_newind  i.ind2 (d_int_air d_int_hea d_drs_air d_drs_hea =d_IV_air  d_IV_hea dist_air dist_hea d_drs0_air d_drs0_hea ) , cluster(citygate) fe first
estimates store col3
estadd local FixedEffects "p-g-f,i" , replace
estadd local cluster "p-g" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col3
estadd scalar test_kp=e(widstat): col3
*xi:ivreg D_newind i.citygate2 i.ind2  (d_int_air d_int_hea d_drs_air d_drs_hea =d_IV_air  d_IV_hea dist_air dist_hea d_drs0_air d_drs0_hea  )
*ivendog d_int_air d_int_hea d_drs_air d_drs_hea
*estadd scalar test_DWH=r(WHF): col3

/* control for industry elasticity of substitution, Broda Weinstein sigma's */

xi:xtivreg2 D_newind  i.ind2 (d_int_air d_int_hea d_int_theta d_drs_air d_drs_hea d_drs_theta =d_IV_air  d_IV_hea d_IV_theta  dist_air dist_hea dist_theta d_drs0_air d_drs0_hea d_drs0_theta) , cluster(citygate) fe first
estimates store col4
estadd local FixedEffects "p-g-f,i" , replace
estadd local cluster "p-g" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col4
estadd scalar test_kp=e(widstat): col4
*xi:ivreg D_newind i.citygate2  i.ind2 (d_int_air d_int_hea d_int_theta d_drs_air d_drs_hea d_drs_theta =d_IV_air  d_IV_hea d_IV_theta  dist_air dist_hea dist_theta d_drs0_air d_drs0_hea d_drs0_theta   )
*ivendog d_int_theta  d_int_air d_int_hea d_drs_air d_drs_hea d_drs_theta 
*estadd scalar test_DWH=r(WHF): col4

/**************/
// Results
/**************/
noi esttab col1 col2 col3 col4, compress width(1\hsize) ///
keep(d_int_air d_int_hea d_int_theta d_drs_air d_drs_hea d_drs_theta) se /// 
star(* 0.10 ** 0.05 *** 0.01) s(Regression N r2 FixedEffects test_ar test_kp test_DWH)


/* variable labels for writing to latex */
label variable dlnval "$\Delta \ln(trade_{pg}^f)$"
label variable D_newind "$Prob(\ln(trade_{pgi}^{f,2012}>0 | Prob(\ln(trade_{pgi}^{f,2012}=0)$"
label variable d_int_air "$\Delta RC_{pg}\times Air_i $"
label variable d_int_hea "$\Delta RC_{pg}\times Heavy_i$"
label variable d_int_theta "$\Delta RC_{pg}\times \Theta_i$"
label variable d_drs_air "$\Delta ers_{pg}\times Air_i$"
label variable d_drs_hea "$\Delta ers_{pg}\times Heavy_i$"
label variable d_drs_theta "$\Delta ers_{pg}\times Theta_i$"

noi esttab col1 col2 col3 col4 using "table11.tex", ///
replace label compress width(1\hsize) ///
keep(d_int_air d_int_hea d_int_theta d_drs_air d_drs_hea d_drs_theta) se star(* 0.10 ** 0.05 *** 0.01) ///
s(Regression N r2 FixedEffects test_ar test_kp test_DWH, label("Regression" "Observations" "$\R^2$" "Fixed Effects" "AR Test Stat." "KP Test Stat." "DWH Test Stat."))

}
log close

translate "Table11.smcl" "Table11.pdf",replace
translate "Table11.smcl" "Table11.ps", replace translator(smcl2ps)
capture erase temp.dta
capture erase temp2.dta
capture erase "Table11.smcl"
