/* Cosar-Demir, Domestic road infrastructure and international trade, JDE final version
Table 5: alternative specifications */

clear all
set more off
log close _all
set matsize 5000

/*Set the directory */
cd "/Users/banudemir/Desktop/replication"

set logtype smcl
log using "Table5", replace

qui{
local yearbeg  = "2004" // cutoff years for long-term differences
local yearend  = "2011"

/****************************/
// Load and prepare the data 
/***************************/
/* construct the instrument */
use "data/market_access_pg.dta",clear
keep if year==2003
keep province_code gateway distpg drs drs_bw
gen RCIV     = (drs-1)*ln(distpg) // instrumental variable
gen RCIVsemi = (drs-1)*(distpg/100)
gen RCIV_bw = (drs_bw-1)*log(distpg)
keep province_code gateway RCIV RCIVsemi RCIV_bw
sort province_code gateway
save temp.dta,replace

/* construct long term divided road share (ers in the paper) */
use "data/market_access_pg.dta",clear
gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.
collapse (mean) distpg drs  drs_bw , by(province_code gateway period)
sort province_code gateway period
reshape wide distpg drs drs_bw,i(province_code gateway) j(period)
rename distpg1 distpg
gen deltadrs         = drs1-drs0
gen deltadrs_bw         = drs_bw1-drs_bw0
drop distpg0 drs_bw1 
sort province_code gateway
save temp2.dta,replace

/* construct dependent variable, change in trade flows */
use "data/data_pgd.dta",clear
drop if wbcode=="TUR" // trade with Turkish Cyprotic Republic
drop if year==.
destring province_code,replace
destring gateway,replace
collapse (sum) exp imp,by(province gateway year)
rename exp value1
rename imp value2
reshape long value, i(year province gateway) j(flow)
gen flowtemp = "exp"
replace flowtemp = "imp" if flow==2
drop flow 
rename flowtemp flow
order year province gate flow
sort year province gate 
drop if value==0
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

/* fill in missing flow-years */
drop if province_code==0 | province_code==99
drop if gateway==0 | gateway==99

fillin  flow year gateway province
replace value=0 if value==.

gen period =.
replace period=0 if year<`yearbeg'
replace period=1 if year>`yearend'
drop if period ==.
collapse (mean) value, by(province_code gateway flow period)
gen lnvalue = ln(value)
reshape wide value lnvalue,i(province_code gateway flow) j(period)

gen dlnval     = lnvalue1-lnvalue0
gen dval       = (value1-value0)/(0.5*(value1+value0)) // Davis & Haltiwanger statistic
drop lnvalue0 lnvalue1 

sort province_code gateway
merge m:m province_code gateway using temp.dta
drop if _merge==2
drop _merge

sort province_code gateway
merge m:m province_code gateway using temp2.dta
drop if _merge==2
drop _merge
 

drop if gateway==6 // see table 3 for explanation

gen lndistpg        = ln(distpg)
gen dRC             = lndistpg * (deltadrs)
gen dRC_bw          = lndistpg * (deltadrs_bw)
replace distpg      = distpg/100
gen dRCsemi         = (distpg) * (deltadrs)

rename province_code city

egen fes        = group(city flow)    // fixed effects
egen fes2       = group(gateway flow)

/**************/
// Regressions
/**************/
// RC based on variation in-between provinces only

xi:ivreg2 dlnval i.fes2 i.fes (dRC_bw deltadrs_bw= RCIV_bw lndistpg drs_bw0) , robust first partial(_cons) //lndistpg
estimates store col1
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col1
estadd scalar test_kp=e(widstat): col1
xi:ivreg dlnval i.fes2 i.fes  (dRC_bw deltadrs_bw= RCIV_bw lndistpg drs_bw0)  
ivendog dRC_bw deltadrs_bw
estadd scalar test_DWH=r(WHF): col1


// semi-log spec
xi:ivreg2 dlnval i.fes2 i.fes  (dRCsemi deltadrs= RCIVsemi distpg drs0) if distpg>0, robust first partial(_cons) // add if distpg>0 here to keep p ~= g consistently with the baseline spec where ln(distpg) is used, and distpg=0 for p=g
estimates store col2
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col2
estadd scalar test_kp=e(widstat): col2
xi:ivreg dlnval i.fes2 i.fes  (dRCsemi deltadrs= RCIVsemi distpg drs0) if distpg>0 // add if distpg>0 here to keep p ~= g consistently with the baseline spec where ln(distpg) is used, and distpg=0 for p=g
ivendog dRCsemi deltadrs
estadd scalar test_DWH=r(WHF): col2

// travel times on the RHS
gen time1      = distpg*drs1/.85 + distpg*(1-drs1)/.80 // since distpg is in 100 km, we use 85km/hr as 0.85
gen time0      = distpg*drs0/.85 + distpg*(1-drs0)/.80
gen dRCtime    = time1-time0

gen time1l      = distpg*drs1/.85 + distpg*(1-drs1)/.80 // since distpg is in 100 km, we use 85km/hr as 0.85
gen time0l      = distpg*drs0/.85 + distpg*(1-drs0)/.80
gen dRCtimel    = time1-time0

xi:ivreg2 dlnval i.fes2 i.fes  (dRCtime deltadrs = time0 drs0) if distpg>0, robust first partial(_cons)
estimates store col3
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col3
estadd scalar test_kp=e(widstat): col3
xi:ivreg dlnval i.fes2 i.fes  (dRCtime deltadrs = time0 drs0) if distpg>0
ivendog dRCtime deltadrs
estadd scalar test_DWH=r(WHF): col3

xi:ivreg2 dlnval i.fes2 i.fes  (dRCtimel deltadrs = time0l drs0) if distpg>0, robust first partial(_cons)
estimates store col3l
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col3l
estadd scalar test_kp=e(widstat): col3l
xi:ivreg dlnval i.fes2 i.fes  (dRCtimel deltadrs = time0l drs0) if distpg>0
ivendog dRCtimel deltadrs
estadd scalar test_DWH=r(WHF): col3l

// replacing dependent variable with David & Haltiwanger measure which keeps the extensive margin in

xi:ivreg2 dval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0) , robust first partial(_cons),if value1!=0
estimates store col4
estadd local FixedEffects "p-f,g-f" , replace
estadd local Regression "IV" , replace
estadd scalar test_ar=e(arf): col4
estadd scalar test_kp=e(widstat): col4
xi:ivreg dval i.fes2 i.fes  (dRC deltadrs= RCIV lndistpg drs0) 
ivendog dRC deltadrs
estadd scalar test_DWH=r(WHF): col4

/**************/
// Results
/**************/
noi esttab col1 col2 col3 col3l col4, compress width(1\hsize) ///
keep( dRC dRC_bw deltadrs_bw deltadrs dRCsemi dRCtime dRCtimel) se /// 
star(* 0.10 ** 0.05 *** 0.01) s(Regression N r2 FixedEffects test_ar test_kp test_DWH psargan)

/* variable labels for writing to latex */
label variable dRC "$\Delta RC_{pg}$"
label variable dRC_bw "$\Delta RC^{bw}_{pg}$"
label variable dRCsemi "$\Delta ers_{pg} \times dist_{pg}$"
label variable dRCtime "$\Delta time$_{pg}"
label variable RCIV "$(\ers_{pg}^{2003}-1)\times\ln dist_{pg}$"
label variable dlnval "$\Delta \ln trade_{pg}^f$"
label variable dval "$\frac{2*(trade_{pg,2012}^f-trade_{pg,2003}^f)}{(trade_{pg,2012}^f+trade_{pg,2003}^f)}$"
label variable deltadrs "$\Delta ers_{pg}$"
label variable deltadrs_bw "$\Delta ers^{bw}_{pg}$"

esttab col1 col2 col3 col4 using "table5.tex",replace label compress width(1\hsize) ///
keep( dRC dRC_bw deltadrs_bw deltadrs dRCsemi dRCtime)  /// 
star(* 0.10 ** 0.05 *** 0.01) se ///
s(Regression N r2 FixedEffects test_ar test_kp test_DWH psargan, ///
label("Regression" "Observations" "$\R^2$" "Fixed Effects" "AR Test Stat." "KP Test Stat." "DWH Test Stat." "Sargan Test Stat."))
}

log close
translate "Table5.smcl" "Table5.pdf", replace
translate "Table5.smcl" "Table5.ps", replace translator(smcl2ps)
capture erase temp.dta
capture erase temp2.dta
capture erase "Table5.smcl"
